@@ -1,7 +1,7 @@
 #Plots all the arcs imported from an ARC file by get.arcdata
 
 #New: T for new plots
-plotarc<-function(arc, new=TRUE)
+plotarc<-function(arc, new=TRUE, ...)
 {
 
 #We only need the list of arcs, not the dataframe with the other data
@@ -25,6 +25,17 @@ bnd[2]<-max(x)
 bnd[3]<-min(y)
 bnd[4]<-max(y)
 
+#Set aspect ratio and display plotting window
+
+par.in <- par(no.readonly = TRUE)
+on.exit(par(par.in))
+
+plot.dim<-c(bnd[3]-bnd[1], bnd[4]-bnd[2])
+
+par(pin = min(par.in$pin) 
+* par.in$fin / max(par.in$fin)
+* (plot.dim) / max(plot.dim))
+
 
 
 for(i in 2:ll)
@@ -52,7 +63,7 @@ range<-max( c(bnd[2]-bnd[1], bnd[4]-bnd[3]) )/2
 xmedian<-(bnd[1]+bnd[2])/2
 ymedian<-(bnd[3]+bnd[4])/2
 
-plot(arc[[1]][[1]], arc[[1]][[2]], xlim=c(xmedian-range,xmedian+range), ylim=c(ymedian-range, ymedian+range), type="n")
+plot(arc[[1]][[1]], arc[[1]][[2]], xlim=c(xmedian-range,xmedian+range), ylim=c(ymedian-range, ymedian+range), type="n", ...)
 
 }##if(new)
 
